*******
Classes
*******

Atoms
-----

.. autosummary::
   :toctree: generated/
   :template: autosummary-class-template.rst
   :recursive:

   toponetx.Atom
   toponetx.Simplex
   toponetx.Path
   toponetx.Cell
   toponetx.HyperEdge

Complexes
---------

.. autosummary::
   :toctree: generated/
   :template: autosummary-class-template.rst
   :recursive:

   toponetx.Complex
   toponetx.SimplicialComplex
   toponetx.PathComplex
   toponetx.CellComplex
   toponetx.CombinatorialComplex
   toponetx.ColoredHyperGraph

Report Views
------------

.. autosummary::
   :toctree: generated/
   :template: autosummary-class-template.rst
   :recursive:

   toponetx.NodeView
   toponetx.AtomView
   toponetx.SimplexView
   toponetx.PathView
   toponetx.CellView
   toponetx.HyperEdgeView
   toponetx.ColoredHyperEdgeView
